import rclpy
from rclpy.node import Node

from geometry_msgs.msg import Twist
from std_msgs.msg import String
from nav_msgs.msg import Odometry

import numpy as np


SCALE_FACTOR = 1.0



class TwistPublisher(Node):
    def __init__(
        self,
        scale_factor=20.0
    ):
        super().__init__("twist_publisher")

        self.scale_factor = scale_factor

        self.publisher_ = self.create_publisher(
            Odometry, "/odom_scaled", 1
        )

        self.create_subscription(Odometry, "/odom", self.odom_callback, 1)

    def odom_callback(self, odom_message:Odometry):
        odom_message.twist.twist.linear.x *= self.scale_factor
        odom_message.twist.twist.linear.y *= self.scale_factor
        odom_message.twist.twist.linear.z *= self.scale_factor
        odom_message.twist.twist.angular.x *= self.scale_factor
        odom_message.twist.twist.angular.y *= self.scale_factor
        odom_message.twist.twist.angular.z *= self.scale_factor
        odom_message.pose.pose.position.x *= self.scale_factor
        odom_message.pose.pose.position.y *= self.scale_factor
        odom_message.pose.pose.position.z *= self.scale_factor
        odom_message.pose.pose.orientation.x *= self.scale_factor
        odom_message.pose.pose.orientation.y *= self.scale_factor
        odom_message.pose.pose.orientation.z *= self.scale_factor

        self.publisher_.publish(odom_message)






def main(args=None):
    rclpy.init(args=args)

    minimal_publisher = TwistPublisher(
        SCALE_FACTOR
    )

    rclpy.spin(minimal_publisher)

    minimal_publisher.destroy_node()
    rclpy.shutdown()


if __name__ == "__main__":
    main()
