import rclpy
from rclpy.node import Node
import tf2_ros
import geometry_msgs.msg as gm


class TF2PublisherNode(Node):

    def __init__(self):
        super().__init__('tf2_publisher_node')
        self.tf_broadcaster = tf2_ros.TransformBroadcaster(self)
        
        self.timer = self.create_timer(0.1, self.publish_identity_transform)

    def send_parent_child_identity_tf(self, parent, child):
        transform_stamped = gm.TransformStamped()
        transform_stamped.header.stamp = self.get_clock().now().to_msg()
        transform_stamped.header.frame_id = parent
        transform_stamped.child_frame_id = child

        # Identity transform (no translation, no rotation)
        transform_stamped.transform.translation.x = 0.0
        transform_stamped.transform.translation.y = 0.0
        transform_stamped.transform.translation.z = 0.0
        transform_stamped.transform.rotation.x = 0.0
        transform_stamped.transform.rotation.y = 0.0
        transform_stamped.transform.rotation.z = 0.0
        transform_stamped.transform.rotation.w = 1.0

        self.tf_broadcaster.sendTransform(transform_stamped)


    def publish_identity_transform(self):
        # self.send_parent_child_identity_tf("map", "odom")
        # self.send_parent_child_identity_tf("odom", "base_link")
       # self.send_parent_child_identity_tf("base_link", "base_scan")
       # self.send_parent_child_identity_tf("base_scan", "velodyne")
        self.send_parent_child_identity_tf("base_link", "velodyne")
        self.send_parent_child_identity_tf("base_link", "base_footprint")
    

        self.get_logger().info('Published identity transform')

def main(args=None):
    rclpy.init(args=args)

    tf2_publisher = TF2PublisherNode()
    rclpy.spin(tf2_publisher)

    tf2_publisher.destroy_node()
    rclpy.shutdown()


if __name__ == '__main__':
    main()
